@@ -1,7 +1,7 @@
 #
-# Id: NoXS.pm,v 2.0 2005/05/16 19:08:02 dankogai Exp
-# $Id: NoXS.pm,v 1.43 2006/03/17 14:00:10 papu Exp $
-# "Jcode.pm" version 2.3 $$
+# Id: NoXS.pm,v 2.0 2005/05/16 19:08:02 dankogai Exp $
+# $Id: NoXS.pm,v 1.52 2007/07/15 07:40:09 papu Exp $
+# "Jcode.pm" version 2.5 $$
 #
 
 package Jcode::Unicode::NoXS;
@@ -9,8 +9,8 @@ package Jcode::Unicode::NoXS;
 use strict;
 use vars qw($RCSID $VERSION);
 
-$RCSID = "Id: NoXS.pm,v 2.0 2005/05/16 19:08:02 dankogai Exp";
-$VERSION = do { my @r = ("Revision: 2.0" =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$RCSID = q$Id: NoXS.pm,v 1.52 2007/07/15 07:40:09 papu Exp $;
+$VERSION = do { my @r = (q$Revision: 1.52 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 use Carp;
 
