@@ -1,12 +1,12 @@
 ######################################################################
 # search_fuzzy.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: search_fuzzy.inc.pl,v 1.52 2006/03/17 14:00:10 papu Exp $
+# $Id: search_fuzzy.inc.pl,v 1.61 2007/07/15 07:40:09 papu Exp $
 #
-# "PyukiWiki" version 0.1.6 $$
+# "PyukiWiki" version 0.1.7 $$
 # Author: Nanami http://lineage.netgamers.jp/
-# Copyright (C) 2004-2006 by Nekyo.
+# Copyright (C) 2004-2007 by Nekyo.
 # http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2006 PyukiWiki Developers Team
+# Copyright (C) 2005-2007 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -26,7 +26,7 @@ use Nana::Search;
 
 sub plugin_fuzzy_search {
 	my $body = "";
-	my $word=&escape(&code_convert(\$::form{search}, $::defaultcode));
+	my $word=&escape(&code_convert(\$::form{mymsg}, $::defaultcode));
 	if ($word) {
 		@words = split(/\s+/, $word);
 		my $total = 0;
@@ -135,9 +135,9 @@ L<http://pyukiwiki.sourceforge.jp/>
 
 =head1 LICENSE
 
-Copyright (C) 2005-2006 by Nanami.
+Copyright (C) 2005-2007 by Nanami.
 
-Copyright (C) 2005-2006 by PyukiWiki Developers Team
+Copyright (C) 2005-2007 by PyukiWiki Developers Team
 
 License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
 
